rayoptics.seq.medium module
===========================

.. automodule:: rayoptics.seq.medium
   :members:
   :undoc-members:
   :show-inheritance:
   :exclude-members: Medium, Air, Glass, InterpolatedGlass
